#pragma once
#include "B4RDefines.h"
#include "SparkFunDS3234RTC.h"
namespace B4R {
	//~Version: 1.0
	//~Shortname: DS3234
    //~Author: Original Library from SparkFun
	class B4RDS3234 {
		private:
            uint8_t sizeRtc[sizeof(DS3234)];
			DS3234* rtc;
		public:
            //Initialize RTC object with given CS/SS pin
			void Initialize(Byte csPin);
            //Return  the hour
            Byte getHour(void);
            //Return the minute
            Byte getMinute(void);
            //Return the second
            Byte getSecond(void);
            //Return the day of the week
            Byte getDay(void);
            //Return the day of the month
            Byte getDate(void);
            //Return the month
            Byte getMonth(void);
            //Return the year
            Byte getYear(void);
            //Set the time (24hr) and date registers
            void SetTime1(Byte sec,Byte min,Byte hour,Byte day,Byte date,Byte month,Byte year);
            //Set the time (12hr) and date registers
            void SetTime2(Byte sec,Byte min,Byte hour,bool pm,Byte day,Byte date,Byte month,Byte year);
            //Return the die temperature, multiples of 0.25 deg C
            float getTemperature(void);
            //Write to chip SRAM, 256 bytes, 0x00-0xFF
            void SRAMWrite(Byte address, Byte data);
            //Read from chip SRAM, 256 bytes, 0x00-0xFF
            Byte SRAMRead(Byte address);
            //Returns TRUE if in 12-hour mode
            bool getIs12Hour(void);
            //Returns TRUE if PM, AM if FALSE
            bool getIsPM(void);
            //Alarm 1 can be set to trigger on seconds, minutes, hours, and/or date/day.
            //Any of those can be ignored for an alarm by setting a value of 255.
            //The "day" boolean if TRUE changes the "date" value from
            //day of the month (1-31) to day fo the week.(1-7).
            void Alarm1(Byte sec,Byte min,Byte hour,Byte date,bool day);
            // Alarm 2 functions like alarm 1, but does not have a seconds value.
            void Alarm2(Byte min,Byte hour,Byte date,bool day);
            //The SQW pin can be used as an interrupt for the alarms.
            //It is active-low and can be set to trigger on alarm 1 and/or alarm 2:
            void AlarmInterrupt(bool alarm1, bool alarm2);
            //Returns TRUE if alarm1 has tripped. Pass TRUE to clear alarm flag.
            bool AlarmStatus1(bool clear);
            //Returns TRUE if alarm2 has tripped. Pass TRUE to clear alarm flag.
            bool AlarmStatus2(bool clear);
            //Enable/disable 12-hour mode
            void Set12Hour(bool enable12);
            //Enable the DS3234's oscillator
            //When powered the oscillator is always on
            void EnableOSC(void);
            //Disable the DS3234's oscillator when on battery power.
            //Disabling the oscillator means no counting!
            void DisableOSC(void);
            //SQW Frequency options
            sqw_rate SQW_1Hz=SQW_SQUARE_1;
            //SQW Frequency options
            sqw_rate SQW_1KHz=SQW_SQUARE_1K;
            //SQW Frequency options
            sqw_rate SQW_4KHz=SQW_SQUARE_4K;
            //SQW Frequency options
            sqw_rate SQW_8KHz=SQW_SQUARE_8K;
            //Set Frequency on SQW pin and enable
            void EnableSQW(sqw_rate value);
	};
}
